@@ -212,6 +212,10 @@ bool wxStfApp::OnInit(void)
                                      wxT("HEKA file"), wxT("*.dat"), wxT(""), wxT("dat"),
                                      wxT("HEKA Document"), wxT("HEKA View"), CLASSINFO(wxStfDoc),
                                      CLASSINFO(wxStfView) );
+    m_intanTemplate=new wxDocTemplate( docManager,
+                                     wxT("Intan CLAMP file"), wxT("*.clp"), wxT(""), wxT("clp"),
+                                     wxT("Intan CLAMP Document"), wxT("Intan View"), CLASSINFO(wxStfDoc),
+                                     CLASSINFO(wxStfView) );
 #if 0
     m_sonTemplate=new wxDocTemplate( docManager,
                                      wxT("CED Spike 2 (SON) file"), wxT("*.smr"), wxT(""), wxT(""),
@@ -672,6 +676,11 @@ wxMenuBar *wxStfApp::CreateUnifiedMenuBar(wxStfDoc* doc) {
                         wxT("S&elect some traces..."),
                         wxT("Select every n-th trace in this file")
                         );
+    m_edit_menu->Append(
+                        ID_SELECT_AND_ADD,
+                        wxT("Se&lect and add traces of type ..."),
+                        wxT("Traces of a certain type are added to the select")
+                        );
     m_edit_menu->Append(
                         ID_UNSELECTALL,
                         wxT("&Unselect all traces\tCtrl+U"),
@@ -682,6 +691,11 @@ wxMenuBar *wxStfApp::CreateUnifiedMenuBar(wxStfDoc* doc) {
                         wxT("U&nselect some traces"),
                         wxT("Unselect some traces in this file")
                         );
+    m_edit_menu->Append(
+                        ID_SELECT_AND_REMOVE,
+                        wxT("Unse&lect traces of type ..."),
+                        wxT("Traces of a certain type are removed from the selection")
+                        );
     wxMenu *editSub=new wxMenu;
     editSub->Append(
                     ID_NEWFROMSELECTEDTHIS,
